#!/usr/bin/env python

import pyinotify
import notify2
from os.path import expanduser
from os import listdir
from mailbox import MaildirMessage
from email.header import decode_header

notify2.init("Mail_notifications")

# Find and list accounts
maildir = '~/.mail'
boxes = { f"{expanduser(maildir)}/{account}" : account for account in listdir(expanduser(maildir)) }

# On new mail
def new_mail(event):
    # Locate new mail
    try:
        fd = open(event.pathname, 'r')
        mail = MaildirMessage(message = fd)
        fd.close()
    except:
        notify2.Notification("Mail notifier", f"Something went wrong in {event.path}\nis there new mail?")
        notify2.show()
        return
    # Extract header info
    try:
        From = mail_head(mail['From'].replace('"', ''))
        To = mail_head(mail['To'])
        Subject = mail_head(mail['Subject'])
    except:
        text = f"New mail in {event.path}\nFailed to decode header"
        notify2.Notification("Mail notifier",text).show()
        return
    # identify which box it came from
    box = [ boxes[box] for box in boxes if box in event.path ]

    notify2.Notification(f"New message in {box[0]}", f"From {From}\n{Subject}").show()


## Not from me, decode and pamper header info
def mail_head(text):
    if not text:
        return ''
    header = []
    for item in decode_header(text):
        try:
            text, encoding = item
        except TypeError:
            text, encoding = ('', None)
        if encoding:
            header.append(str(text.decode(encoding)))
        else:
            if isinstance(text, bytes):
                text = text.decode('utf-8')
            header.append(str(text))
    return ' '.join(header)

# Set up the file watcher and notification system
wm = pyinotify.WatchManager()
notifier = pyinotify.Notifier(wm,new_mail)

for box in boxes:
    wm.add_watch(box+"/Inbox/new", pyinotify.IN_CREATE | pyinotify.IN_MOVED_TO )

notifier.loop()
