#!/bin/bash

### A simple script I use to add a mailbox to mutt
## Inform the script about the specifics of your mailbox (mail, user name, password, ...)
## The script will then write:
## * .mbsyncrc to configure the imap part
## * .msmtprc to configure the smtp part
## * .mutt/accounts, .mutt/$account and .mutt/sidebar-accounts for the mutt part
##
## This provides a basic config, which may have to be modified afterwards for specific uses


echo 
echo "-----------------------"
echo "----- ADD MAILBOX -----"
echo "-----------------------"
echo 

### Get info

read -p "account name: " account
read -p "mail address: " mail
# grep the domain name
domain=$(echo $mail | grep -o "@[[:alnum:][:graph:]]*" | sed -e 's/@//g')
read -p "user name (defaults as $mail): " user
if [ -z $user ];then user=$mail;fi
read -p "full name: " name
read -p "signature (defaults to $name): " sign
if [ -z $sign ];then sign=$name;fi
read -p "imap server (defaults to imap.$domain): " imap
if [ -z $imap ];then imap="imap.$domain";fi
read -p "smtp server (defaults to smtp.$domain): " smtp
if [ -z $smtp ];then smtp="smtp.$domain";fi
read -p "smtp port (defaults to 587): " sport
if [ -z $sport ];then sport=587;fi
read -p "Use plaintext pass? [y/N]: " choice
if [ -z $choice ] || [ $choice = "N" ] || [ $choice = "n" ];then
        read -p "password evaluation command: " password
    else
        read -p "Password: " password
fi


### Write files

## .mbsyncrc
outfile=$HOME/.mbsyncrc
if [ -z $choice ] || [ $choice = "n" ] || [ $choice = "N" ];then
    passcmd=PassCmd
else
    passcmd=Password
fi

if [ ! -f $outfile ];then
echo "# ########### #
#  .mbsyncrc  #
# ########### #

# from https://gist.github.com/chandraratnam/f00ab7d4a5298830f692021964fdb99f

Create Both
Expunge Both
SyncState *
">>$outfile
fi

echo "## $account {{{

IMAPAccount $account
# Account info
Host $imap
User $user
$passcmd \"$password\"
# Use SSL
SSLType IMAPS
CertificateFile /etc/ssl/certs/ca-certificates.crt
AuthMechs LOGIN

IMAPStore $account-remote
Account $account

MaildirStore $account-local
Subfolders Verbatim
Path ~/.mail/$account/
Inbox ~/.mail/$account/Inbox

Channel $account
Master :$account-remote:
Slave :$account-local:
Patterns "INBOX" "Sent" "Trash" "Drafts"
# }}}">>$outfile

mkdir $HOME/.mail/$account


## .msmtprc
outfile=$HOME/.msmtprc
if [ -z $choice ] || [ $choice = "n" ] || [ $choice = "N" ];then
    passcmd=passwordeval
else
    passcmd=password
fi

if [ ! -f $outfile ];then
echo "# ########## #
#  .msmtprc  #
# ########## #


## General config {{{

# Set default values for all following accounts.
defaults
auth           on
tls            on
tls_trust_file /etc/ssl/certs/ca-certificates.crt
logfile        ~/.msmtp.log
# }}} 
">>$outfile
fi

echo "
## $account {{{

account         $account
host            $smtp
port            $sport
from            $mail
user            $user
$passcmd       \"$password\"
# }}}">>$outfile


## .mutt/accounts
outfile=$HOME/.mutt/accounts
if [ ! -f $outfile ];then
echo "### Accounts configuration"
fi

echo "## $account {{{
source "~/.mutt/$account"
folder-hook \$folder 'source ~/.mutt/$account'
# Change inbox (and source)
macro index,pager <f2> '<enter-command>source ~/.mutt/$account<enter><change-folder>!<enter>'
# }}}">>$outfile

## .mutt/$account
# It is assumed that .mutt/$account does not exist yet
outfile=$HOME/.mutt/$account
echo "color status yellow default
## Receive options.
set folder = "~/.mail/$account"
set spoolfile = +Inbox
set postponed = +Drafts
set record = +Sent

## Send options.
set realname='$name'
set from = \"$mail\"
set sendmail = \"/usr/bin/msmtp -a $account\"
set sendmail_wait = 0 # Wait for mail to be sent before going back to mail list
unset record # Do not record sent mails (done server side)
set signature=\"$name\"">>$outfile

## .mutt/sidebar-accounts
outfile=$HOME/.mutt/sidebar-accounts
if [ ! -f $outfile ];then
echo "### Add the relevant boxes to the sidebar
# vim: ft=muttrc"
fi

echo "mailboxes -label $account '~/.mail/$account/Inbox'">>$outfile
